Re-exports
pub use compat::pubkey;
Modules
Macros
- declare_
id - Convenience macro to declare a static public key and functions to interact with it.
- pubkey
- Convenience macro to define a static
Addressvalue.
Structs
- Pubkey
- The address of a Solana account.
Constants
- CALLBACK_
PROGRAM_ ID - CRANK_
PROGRAM_ ID - EPHEMERAL_
RENT_ PER_ BYTE - Rent rate for ephemeral accounts: 32 lamports per byte. This is ~109x cheaper than Solana’s base rent (3,480 lamports/byte).
- EPHEMERAL_
VAULT_ PUBKEY - Vault account that collects rent for ephemeral accounts.
- ID
- The const program ID.
- MAGIC_
CONTEXT_ PUBKEY - MAGIC_
CONTEXT_ SIZE - We believe 5MB should be enough to store all scheduled commits within a slot. Once we store more data in the magic context we need to reconsicer this size. NOTE: the default max accumulated account size per transaction is 64MB. See: MAX_LOADED_ACCOUNTS_DATA_SIZE_BYTES inside program-runtime/src/compute_budget_processor.rs
- POST_
DELEGATION_ ACTION_ EXECUTOR_ PROGRAM_ ID