pub struct AddActionCallbackArgs {
pub action_index: u8,
pub destination_program: Pubkey,
pub discriminator: Vec<u8>,
pub payload: Vec<u8>,
pub compute_units: u32,
pub accounts: Vec<ShortAccountMeta>,
}Fields
action_index: u8Flat index of the action to attach the callback to, ordered as: commit actions, commit_and_undelegate commit actions, commit_and_undelegate undelegate actions, standalone actions.
destination_program: Pubkeydiscriminator: Vec<u8>payload: Vec<u8>compute_units: u32accounts: Vec<ShortAccountMeta>Trait Implementations
Sourceimpl Clone for AddActionCallbackArgs
impl Clone for AddActionCallbackArgs
Sourcefn clone(&self) -> AddActionCallbackArgs
fn clone(&self) -> AddActionCallbackArgs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddActionCallbackArgs
impl Debug for AddActionCallbackArgs
Sourceimpl<'de> Deserialize<'de> for AddActionCallbackArgs
impl<'de> Deserialize<'de> for AddActionCallbackArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AddActionCallbackArgs
impl PartialEq for AddActionCallbackArgs
Sourcefn eq(&self, other: &AddActionCallbackArgs) -> bool
fn eq(&self, other: &AddActionCallbackArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AddActionCallbackArgs
impl Serialize for AddActionCallbackArgs
impl Eq for AddActionCallbackArgs
impl StructuralPartialEq for AddActionCallbackArgs