pub struct MagicResponseV1 {
pub ok: bool,
pub data: Vec<u8>,
pub error: String,
pub receipt: Option<ActionReceipt>,
}Fields
ok: booldata: Vec<u8>Data user specified as payload for callback Present even in case of an error
error: StringReason for callback execution with ok = false TimeoutError/ActionError
receipt: Option<ActionReceipt>Action execution receipt entries Present if signature of action tx is available