Re-exports
pub use solana_program::pubkey;
Macros
- declare_
id - Convenience macro to declare a static public key and functions to interact with it.
- pubkey
- Convenience macro to define a static
Addressvalue.
Structs
- Account
Info - Account information
- Account
Meta - Describes a single account read or written by a program during instruction execution.
- Instruction
- A directive for a single invocation of a Solana program.
- Pubkey
- The address of a Solana account.
- Signature